Learn R Programming

bisoreg (version 1.0)

bisoreg-package: Bayesian Isotonic Regression with Bernstein Polynomials

Description

The function bisoreg implements the procedure described in the paper "A Bayesian variable selection approach to monotonic regression." The package also contains additional functions to compare with the Bayesian method in the paper.

Arguments

Details

ll{ Package: bisoreg Type: Package Version: 1.0 Date: 2008-10-07 License: GPL (>=2) LazyLoad: yes }

References

Curtis, S. M. and Ghosh, S. K. (2009) "A variable selection approach to monotonic regression with Bernstein polynomials." (unpublished manuscript).

Examples

Run this code
## See examples for bisoreg ##

Run the code above in your browser using DataLab