This data set is the onechild dataset from the fda package.
childgrowthA data.frame containing 83 observations on two variables.
day is day of the year on which the height measurement was taken.
height is the height in inches of the child.
Ramsay, James O., and Silverman, Bernard W. (2002). Applied Functional Data Analysis 2nd ed. Springer, New York.
Tuddenham, R. D., and Snyder, M. M. (1954). "Physical growth of California boys and girls from birth to age 18", University of California Publications in Child Development, 1, 183-364.